@@ -52,9 +52,16 @@ class CallbackContext(object):
 		self._args = args
 
 		# Create members for easy access.
+		exp = re.compile('[^0-9a-zA-Z_]')
 		for argName, argValue in args.iteritems():
-			# Create argument. Do not set its value with exec since handling
-			exec('self.{0} = "{1}"'.format(argName, argValue))
+			# Rename args to comply with Python naming rules.
+			changedName = re.sub(exp, '_', argName)
+			if changedName != argName:
+				logger.reportWarning('Argument {0} renamed to {1} to comply with naming rules.'.format(argName, changedName))
+
+			# Create argument.
+			exec('self.{0} = "{1}"'.format(changedName, argValue))
+
 		if args.has_key('objectId'):
 			self._object = self.linknx.getObject(self.objectId)
 		else:
